@@ -120,11 +120,6 @@ escl_devcaps_source_parse_color_modes (xml_rd *xml, devcaps_source *src)
     }
     xml_rd_leave(xml);
 
-    src->colormodes &= DEVCAPS_COLORMODES_SUPPORTED;
-    if (src->colormodes == 0) {
-        return ERROR("no color modes detected");
-    }
-
     return NULL;
 }
 
@@ -288,10 +283,6 @@ escl_devcaps_source_parse_resolutions (xml_rd *xml, devcaps_source *src)
         src->flags &= ~DEVCAPS_SOURCE_RES_RANGE;
     }
 
-    if (!(src->flags & (DEVCAPS_SOURCE_RES_DISCRETE|DEVCAPS_SOURCE_RES_RANGE))){
-        err = ERROR("scan resolutions are not defined");
-    }
-
     return err;
 }
 
@@ -302,6 +293,7 @@ escl_devcaps_source_parse_setting_profiles (xml_rd *xml, devcaps_source *src)
 {
     error err = NULL;
 
+    /* Parse setting profiles */
     xml_rd_enter(xml);
     for (; err == NULL && !xml_rd_end(xml); xml_rd_next(xml)) {
         if (xml_rd_node_name_match(xml, "scan:SettingProfile")) {
@@ -322,6 +314,24 @@ escl_devcaps_source_parse_setting_profiles (xml_rd *xml, devcaps_source *src)
     }
     xml_rd_leave(xml);
 
+    /* Validate results */
+    if (err == NULL) {
+        src->colormodes &= DEVCAPS_COLORMODES_SUPPORTED;
+        if (src->colormodes == 0) {
+            return ERROR("no color modes detected");
+        }
+
+        src->formats &= DEVCAPS_FORMATS_SUPPORTED;
+        if (src->formats == 0) {
+            return ERROR("no image formats detected");
+        }
+
+        if (!(src->flags & (DEVCAPS_SOURCE_RES_DISCRETE|
+                            DEVCAPS_SOURCE_RES_RANGE))){
+            return ERROR("scan resolutions are not defined");
+        }
+    }
+
     return err;
 }
 
@@ -440,9 +450,11 @@ static error
 escl_devcaps_parse (proto_handler_escl *escl,
         devcaps *caps, const char *xml_text, size_t xml_len)
 {
-    error  err = NULL;
-    xml_rd *xml;
-    bool   quirk_canon_iR2625_2630 = false;
+    error     err = NULL;
+    xml_rd    *xml;
+    bool      quirk_canon_iR2625_2630 = false;
+    ID_SOURCE id_src;
+    bool      src_ok = false;
 
     /* Parse capabilities XML */
     err = xml_rd_begin(&xml, xml_text, xml_len, NULL);
@@ -502,9 +514,6 @@ escl_devcaps_parse (proto_handler_escl *escl,
     }
 
     /* Check that we have at least one source */
-    ID_SOURCE id_src;
-    bool      src_ok = false;
-
     for (id_src = (ID_SOURCE) 0; id_src < NUM_ID_SOURCE; id_src ++) {
         if (caps->src[id_src] != NULL) {
             src_ok = true;
