@@ -990,6 +990,7 @@ http_uri_strip_zone_suffux (http_uri *uri)
 
     /* Update host */
     host = alloca(len + 1);
+    memcpy(host, field.str, len);
     host[len] = '\0';
 
     http_uri_field_replace(uri, UF_HOST, host);
@@ -1258,7 +1259,7 @@ http_hdr_parse (http_hdr *hdr, const char *data, size_t size, bool skip_line)
         .on_header_value     = http_hdr_on_header_value,
         .on_headers_complete = http_hdr_on_headers_complete
     };
-    http_parser parser;
+    http_parser parser = {0};
     static char prefix[] = "HTTP/1.1 200 OK\r\n";
 
     /* Skip first line, if requested */
@@ -2531,6 +2532,16 @@ http_query_callbacks = {
     .on_message_complete = http_query_on_message_complete
 };
 
+/* Set http_query::fdpoll event mask
+ */
+static void
+http_query_fdpoll_set_mask (http_query *q, ELOOP_FDPOLL_MASK mask)
+{
+    ELOOP_FDPOLL_MASK old_mask = eloop_fdpoll_set_mask(q->fdpoll, mask);
+    log_debug(q->client->log, "HTTP fdpoll: %s -> %s",
+        eloop_fdpoll_mask_str(old_mask), eloop_fdpoll_mask_str(mask));
+}
+
 /* http_query::fdpoll callback
  */
 static void
@@ -2566,7 +2577,7 @@ http_query_fdpoll_callback (int fd, void *data, ELOOP_FDPOLL_MASK mask)
         log_debug(q->client->log, "HTTP done TLS handshake");
 
         q->handshake = false;
-        eloop_fdpoll_set_mask(q->fdpoll, ELOOP_FDPOLL_BOTH);
+        http_query_fdpoll_set_mask(q, ELOOP_FDPOLL_BOTH);
     } else if (q->sending) {
         rc = http_query_sock_send(q, q->rq_buf + q->rq_off, len);
 
@@ -2603,7 +2614,7 @@ http_query_fdpoll_callback (int fd, void *data, ELOOP_FDPOLL_MASK mask)
             log_debug(q->client->log, "HTTP done request sending");
 
             q->sending = false;
-            eloop_fdpoll_set_mask(q->fdpoll, ELOOP_FDPOLL_BOTH);
+            http_query_fdpoll_set_mask(q, ELOOP_FDPOLL_BOTH);
 
             /* Initialize HTTP parser */
             http_parser_init(&q->http_parser, HTTP_RESPONSE);
@@ -2730,7 +2741,7 @@ AGAIN:
         q->handshake = true;
     }
     q->sending = true;
-    eloop_fdpoll_set_mask(q->fdpoll, ELOOP_FDPOLL_WRITE);
+    http_query_fdpoll_set_mask(q, ELOOP_FDPOLL_WRITE);
 }
 
 /* Close connection to the server, if any
@@ -2838,7 +2849,7 @@ http_query_sock_err (http_query *q, int rc)
     }
 
     if (mask != 0) {
-        eloop_fdpoll_set_mask(q->fdpoll, mask);
+        http_query_fdpoll_set_mask(q, mask);
     }
 
     return err;
