@@ -352,6 +352,14 @@ str_dup (const char *s1)
     return s;
 }
 
+/* Get string length in bytes, not including terminating '\0'
+ */
+static inline size_t
+str_len (const char *s)
+{
+    return mem_len(s);
+}
+
 /* Create new string as a lowercase copy of existent string
  */
 char*
@@ -398,7 +406,7 @@ str_resize (char *s, size_t len)
 static inline char*
 str_append_mem (char *s1, const char *s2, size_t l2)
 {
-    size_t l1 = mem_len(s1);
+    size_t l1 = str_len(s1);
 
     s1 = mem_resize(s1, l1 + l2, 1);
     memcpy(s1 + l1, s2, l2);
@@ -472,7 +480,7 @@ str_concat (const char *s, ...);
 static inline char*
 str_terminate (char *s, char c)
 {
-    if (s[0] != '\0' && s[mem_len(s) - 1] != c) {
+    if (s[0] != '\0' && s[str_len(s) - 1] != c) {
         s = str_append_c(s, c);
     }
 
@@ -905,67 +913,6 @@ inifile_read (inifile *file);
 bool
 inifile_match_name (const char *n1, const char *n2);
 
-/******************** Configuration file loader ********************/
-/* Device URI for manually disabled device
- */
-#define CONF_DEVICE_DISABLE     "disable"
-
-/* Device configuration, for manually added devices
- */
-typedef struct conf_device conf_device;
-struct conf_device {
-    unsigned int devid; /* Device ident */
-    const char   *name; /* Device name */
-    ID_PROTO     proto; /* Protocol to use */
-    http_uri     *uri;  /* Device URI, parsed; NULL if device disabled */
-    conf_device  *next; /* Next device in the list */
-};
-
-/* WSDD_MODE represents WS-Discovery mode
- */
-typedef enum {
-    WSDD_FAST,  /* Use hints from DNS-SD to speed up WSDD */
-    WSDD_FULL,  /* Full discovery, slow and fair */
-    WSDD_OFF    /* Disable WSDD */
-} WSDD_MODE;
-
-/* Backend configuration
- */
-typedef struct {
-    bool        dbg_enabled;      /* Debugging enabled */
-    const char  *dbg_trace;       /* Trace directory */
-    conf_device *devices;         /* Manually configured devices */
-    bool        discovery;        /* Scanners discovery enabled */
-    bool        model_is_netname; /* Use network name instead of model */
-    bool        proto_auto;       /* Auto protocol selection */
-    WSDD_MODE   wsdd_mode;        /* WS-Discovery mode */
-    const char  *socket_dir;      /* Directory for AF_UNIX sockets */
-} conf_data;
-
-#define CONF_INIT {                     \
-        .dbg_enabled = false,           \
-        .dbg_trace = NULL,              \
-        .devices = NULL,                \
-        .discovery = true,              \
-        .model_is_netname = true,       \
-        .proto_auto = true,             \
-        .wsdd_mode = WSDD_FAST,         \
-        .socket_dir = NULL              \
-    }
-
-extern conf_data conf;
-
-/* Load configuration. It updates content of a global conf variable
- */
-void
-conf_load (void);
-
-/* Free resources, allocated by conf_load, and reset configuration
- * data into initial state
- */
-void
-conf_unload (void);
-
 /******************** Utility functions for IP addresses ********************/
 /* Address string, wrapped into structure so can
  * be passed by value
@@ -1104,6 +1051,23 @@ ip_addr_equal (ip_addr a1, ip_addr a2)
     return false;
 }
 
+/* ip_network represents IPv4 or IPv6 network (i.e., address with mask)
+ */
+typedef struct {
+    ip_addr addr; /* Network address */
+    int     mask; /* Network mask */
+} ip_network;
+
+/* Format ip_network into ip_straddr
+ */
+ip_straddr
+ip_network_to_straddr (ip_network net);
+
+/* Check if ip_network contains ip_addr
+ */
+bool
+ip_network_contains (ip_network net, ip_addr addr);
+
 /* ip_addr_set represents a set of IP addresses
  */
 typedef struct ip_addrset ip_addrset;
@@ -1160,6 +1124,12 @@ ip_addrset_addresses (const ip_addrset *addrset, size_t *count);
 bool
 ip_addrset_is_intersect (const ip_addrset *set, const ip_addrset *set2);
 
+/* Check if some of addresses in the address set is on the
+ * given network
+ */
+bool
+ip_addrset_on_network (const ip_addrset *set, ip_network net);
+
 /* Create user-friendly string out of set of addresses, containing
  * in the ip_addrset:
  *   * addresses are sorted, IP4 addresses goes first
@@ -1295,6 +1265,78 @@ netif_init (void);
 void
 netif_cleanup (void);
 
+/******************** Configuration file loader ********************/
+/* Device URI for manually disabled device
+ */
+#define CONF_DEVICE_DISABLE     "disable"
+
+/* Device configuration, for manually added devices
+ */
+typedef struct conf_device conf_device;
+struct conf_device {
+    unsigned int devid; /* Device ident */
+    const char   *name; /* Device name */
+    ID_PROTO     proto; /* Protocol to use */
+    http_uri     *uri;  /* Device URI, parsed; NULL if device disabled */
+    conf_device  *next; /* Next device in the list */
+};
+
+/* WSDD_MODE represents WS-Discovery mode
+ */
+typedef enum {
+    WSDD_FAST,  /* Use hints from DNS-SD to speed up WSDD */
+    WSDD_FULL,  /* Full discovery, slow and fair */
+    WSDD_OFF    /* Disable WSDD */
+} WSDD_MODE;
+
+/* Device blacklist entry
+ */
+typedef struct conf_blacklist conf_blacklist;
+struct conf_blacklist {
+    const char     *model;   /* If not NULL, match by model */
+    const char     *name;    /* If not NULL, match by network name */
+    ip_network     net;      /* if net.addr.af != AF_UNSPEC, match by net */
+    conf_blacklist *next;    /* Next entry in the list */
+};
+
+/* Backend configuration
+ */
+typedef struct {
+    bool           dbg_enabled;      /* Debugging enabled */
+    const char     *dbg_trace;       /* Trace directory */
+    conf_device    *devices;         /* Manually configured devices */
+    bool           discovery;        /* Scanners discovery enabled */
+    bool           model_is_netname; /* Use network name instead of model */
+    bool           proto_auto;       /* Auto protocol selection */
+    WSDD_MODE      wsdd_mode;        /* WS-Discovery mode */
+    const char     *socket_dir;      /* Directory for AF_UNIX sockets */
+    conf_blacklist *blacklist;       /* Devices blacklisted for discovery */
+} conf_data;
+
+#define CONF_INIT {                     \
+        .dbg_enabled = false,           \
+        .dbg_trace = NULL,              \
+        .devices = NULL,                \
+        .discovery = true,              \
+        .model_is_netname = true,       \
+        .proto_auto = true,             \
+        .wsdd_mode = WSDD_FAST,         \
+        .socket_dir = NULL              \
+    }
+
+extern conf_data conf;
+
+/* Load configuration. It updates content of a global conf variable
+ */
+void
+conf_load (void);
+
+/* Free resources, allocated by conf_load, and reset configuration
+ * data into initial state
+ */
+void
+conf_unload (void);
+
 /******************** Pollable events ********************/
 /* The pollable event
  *
@@ -1474,6 +1516,11 @@ typedef enum {
     ELOOP_FDPOLL_BOTH  = ELOOP_FDPOLL_READ | ELOOP_FDPOLL_WRITE
 } ELOOP_FDPOLL_MASK;
 
+/* Convert ELOOP_FDPOLL_MASK to string. Used for logging.
+ */
+const char*
+eloop_fdpoll_mask_str (ELOOP_FDPOLL_MASK mask);
+
 /* Create eloop_fdpoll
  *
  * Callback will be called, when file will be ready for read/write/both,
@@ -1491,9 +1538,9 @@ eloop_fdpoll_new (int fd,
 void
 eloop_fdpoll_free (eloop_fdpoll *fdpoll);
 
-/* Set eloop_fdpoll event mask
+/* Set eloop_fdpoll event mask. It returns a previous value of event mask
  */
-void
+ELOOP_FDPOLL_MASK
 eloop_fdpoll_set_mask (eloop_fdpoll *fdpoll, ELOOP_FDPOLL_MASK mask);
 
 /* Format error string, as printf() does and save result
